# Copyright Louis Paternault 2017-2022
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Markdown README renderer"""

import markdown

from . import HtmlReadmeRenderer


class MdwnReadmeRenderer(HtmlReadmeRenderer):
    """Markdown renderer for readme files."""

    keyword = "renderer.html.readme.mdwn"
    extensions = ["mdwn", "md"]

    def render(self, tree):
        """Render file as html code."""
        with open(tree.from_fs, encoding="utf8") as source:
            return markdown.markdown(source.read())
